#! /bin/sh -x
#+
#
# ===========
# genaeres.sh
# ===========
#
# SYNOPSIS
# ========
#
# ``./genaeres.sh``
#
# DESCRIPTION
# ===========
#
# aeres 2007-2012
#
# SEE ALSO
# ========
#
# genbib.sh
#
# TODO
# ====
#
# integrer dans trunk superbib
#
# on ne voit pas les notes des unpublished dans le pdf plain
#
# EVOLUTIONS
# ==========
#
# $Id$
#
# $URL$
#
# - fplod 20120912T124959Z cratos.locean-ipsl.upmc.fr (Linux)
#
#   * homogenize log message with command and LINENO
#   * get info from aeres subset instead of the whole biblio (ie year limit)
#   * produce a RTF file by team
#
# - fplod 20120706T101813Z cratos (Linux)
#
#   * add phybiocar theme (bouzin mais a marche)
#
# - fplod 20120705T101524Z cratos (Linux)
#
#   * nouvelle technique de slection avec bib2bib
#     donc les unpublished avec des champs year sont maintenant slectionns
#     thanks to http://www.lri.fr/~filliatr/bibtex2html/doc/manual.html#htoc14
#   * intgration de genaeres_rtf.sh
#
# - fplod 20120419T121614Z cratos (Linux)
#
#   * add copy of sorttable.js in dirwww
#   * add copy of sorttable.css in dirwww
#
# - fplod 20120406
#
#   * creation sans rpter certaines fonctionalits de genbib.sh
#     comme les vrif. de bases, les tutuelles
#
#-
set -u
command=$(basename ${0})
#
system=$(uname)
case "${system}" in
   AIX|IRIX64)
      echo "${command} : ${LINENO} : www : no specific posix checking"
   ;;
   *)
      set -o posix
   ;;
esac
#
. define_teams_aeres2007_2012.sh
. define_phybiocar_theme.sh
. jabref_rtf.sh
. jabref_header.sh
. define_authors.sh
#
log_date=$(date -u +"%Y%m%dT%H%M%SZ")
log=${PROJECT_LOG}/$(basename ${command} .sh).log.${log_date}
#
usage=" Usage : ${command}"
#
# test if bibtool available
tool=bibtool
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : ${LINENO} : eee : ${tool} unavailable" >&2
   exit 1
fi
unset tool
unset status
#
# test if bib2bib available
tool=bib2bib
type ${tool} 1> /dev/null 2>&1
status=${?}
if [ ${status} -ne 0 ]
then
   echo "${command} : ${LINENO} : eee : ${tool} unavailable" >&2
   exit 1
fi
unset tool
unset status
#
# default
# n.a.
#
tmpdir=${PROJECT_LOG}/gtbiblio/aeres2007_2012/
dirwww=${PROJECT_OD}/public_html/gtbiblio/aeres2007_2012/
rm -rf ${tmpdir} 2> /dev/null
mkdir -p ${tmpdir}
rm -rf ${dirwww} 2> /dev/null
mkdir -p ${dirwww}
#
# copy javascript and css for sort table in  output directory
cp sorttable.js ${dirwww}/
cp sorttable.css ${dirwww}/
#
# define bibliography reference file
biblioref_orig=${PROJECT_ID}/biblioref.bib
biblioreffull=${tmpdir}/all.bib
cp ${biblioref_orig} ${biblioreffull}
biblioref=${tmpdir}/aeres2007_2012.bib
bibliocite=${tmpdir}/aeres2007_2012_cite.bib
#
bib2bib -oc ${bibliocite} -ob ${biblioref} \
        -c 'year>=2007 and year<=2012' \
        ${biblioreffull}
#
# ++ usefull artificial header of jabref file to enforce encoding
jabref_header ${tmpdir}/header_jabref
#
# gnration du PDF classique
list_style="plain" #+++
for style in ${list_style}
do
   rm ${dirwww}/$(basename ${biblioref}.${style}.log .log).* 2> /dev/null
   # generation of latex file
   cat << EOF > ${biblioref}.${style}.tex
\documentclass[a4paper]{article}
%++\usepackage[frenchb]{babel}
\usepackage[latin1]{inputenc}
\begin{document}
% force to include all entry of the bibliography
\nocite{*}

% bibliography
\bibliographystyle{${style}}

\bibliography{${biblioref}}
\end{document}
EOF
   #
   # processing bibliography with pdflatex (${dirwww}/${biblioref}.${style}.pdf)
   rm ${dirwww}/$(basename ${biblioref}.${style}.log .log).* 2> /dev/null
   pdflatex -output-directory ${dirwww} ${biblioref}.${style}.tex
   bibtex ${dirwww}/$(basename ${biblioref}.${style})
   #++ warnings
   pdflatex -output-directory ${dirwww} ${biblioref}.${style}.tex
   pdflatex -output-directory ${dirwww} ${biblioref}.${style}.tex
   #
   # remove temporary latex files
   rm ${dirwww}/$(basename ${biblioref}.${style}.bbl) ${dirwww}/$(basename ${biblioref}.${style}.blg) ${dirwww}/$(basename ${biblioref}.${style}.log) ${dirwww}/$(basename ${biblioref}.${style}.aux) 2> /dev/null
   #
   #++rm ${biblioref}.${style}.tex 2> /dev/null
done

echo "fin 1re passe latex"

# generation one RTF file style harvard
output_title=aeres2007_2012
rm ${biblioref}.harvard.jabref.rtf 2> /dev/null
java -jar ${JABREF_DIR}/JabRef-${JABREF_VERSION}.jar -n true \
-p ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
--output ${dirwww}/${output_title}.harvard.jabref.rtf,harvard \
${biblioref}
echo "fin rtf all"
#
# generation of HTML
list_format="html simplehtml tablerefs locean_tablerefs locean_tablerefsabsbibsort locean_listrefs"
for format in ${list_format}
do
   echo "format export jabref ${format}"
   # generation one HTML file style ${format}
   rm ${biblioref}.${format}.jabref.html 2> /dev/null
   java -jar ${JABREF_DIR}/JabRef-${JABREF_VERSION}.jar -n true \
   -p ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
   --output ${dirwww}/${output_title}.${format}.jabref.html,${format} \
   ${biblioref}
   jabref_status=${?}
   if [ ${jabref_status} -ne 0 ]
   then
      echo "${command} : ${LINENO} : eee : pb with jabref export ${format}"
      exit 1
   fi
done
#
# loop on teams and years to build bibliography reference file
list_fteamyear=""
iteam=1
nbteam=${#list_team_bibtool[@]}
while [ ${iteam} -le ${nbteam} ]
do
    echo "${command} : ${LINENO} : iii : team = ${list_team_bibtool[${iteam}]}"
    fteam=${tmpdir}/${list_team_title[${iteam}]}.bib
    rm ${fteam} 2> /dev/null
    bibtool_command="bibtool -- 'select={aeresteam \"${list_team_bibtool[${iteam}]}\"}' ${biblioref} -o ${fteam}"
    eval ${bibtool_command}
    unset bibtool_command
    nbatteam=$(grep -c @ ${fteam})
    if [ ${nbatteam} -ge 2 ]
    then
        echo "${command} : ${LINENO} : iii : $((${nbatteam} - 1)) ref for aeresteam ${list_team_title[${iteam}]}"
        # generation one HTML file style ${format}
        format=locean_tablerefsabsbibsort
        rm ${biblioref}.${format}.jabref.html 2> /dev/null
        java -jar ${JABREF_DIR}/JabRef-${JABREF_VERSION}.jar -n true \
           -p ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
           --output ${dirwww}/${output_title}_${list_team_title[iteam]}.${format}.jabref.html,${format} \
           ${fteam}
        jabref_status=${?}
        if [ ${jabref_status} -ne 0 ]
        then
           echo "${command} : ${LINENO} : eee : pb with jabref export ${format}"
           exit 1
        fi
        # generation one RTF file
        ofteam=${dirwww}/$(basename ${fteam} .bib).rtf
        rm ${ofteam} 2> /dev/null
        jabref_rtf \
          ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
          ${fteam} ${ofteam}
        jabref_status=${?}
        if [ ${jabref_status} -ne 0 ]
        then
           echo "${command} : ${LINENO} : eee : pb with jabref rtf team"
           exit 1
        fi
        # loop on years
        list_year=$(seq 2007 2012)
        for iyear in ${list_year}
        do
           echo "${command} : ${LINENO} : iii : year = ${iyear}"
           fteamyear=${tmpdir}/$(basename ${fteam} .bib)_${iyear}.bib
           rm  ${fteamyear} 2> /dev/null
           bibtool_command="bibtool -- 'select={year \"${iyear}\"}' ${fteam} -o ${fteamyear}"
           eval ${bibtool_command}
           unset bibtool_command
           # test if empty
           nbatteamyear=$(grep -c @ ${fteamyear})
           if [ ${nbatteamyear} -ge 2 ]
           then
               echo "${command} : ${LINENO} : iii : $((${nbatteamyear} - 1)) ref for aeresteam ${list_team_title[${iteam}]} and year ${iyear}"
               list_fteamyear="${list_fteamyear} ${fteamyear}"
           else
               echo "${command} : ${LINENO} : www : no ref for aeresteam ${list_team_title[${iteam}]} and year ${iyear}"
           fi
           unset nbatteamyear
       done # end of year loop
       unset iyear
    else
       echo "${command} : ${LINENO} : www : no ref for aeresteam ${list_team_title[${iteam}]}"
    fi
    unset nbatteam
    unset nbatteamyear
    iteam=$(( ${iteam} + 1 ))
done # end of team loop
unset iteam
unset nbteam
unset list_year
unset fteam
#
# define jabref header
# ++ usefull
jabref_header ${tmpdir}/header_jabref
#
# loop on aerestype
list_aerestype="ACL ACLN ASCL BRE C-INV C-ACTI C-ATCN C-COM C-AFF DO OR OS PV PAT PT AP"
for aerestype in ${list_aerestype}
do
   echo "${command} : ${LINENO} : iii : aerestype = ${aerestype}"
   for fteamyear in ${list_fteamyear}
   do
      echo "${command} : ${LINENO} : iii : fteamyear = ${fteamyear}"
      #++ add header
      fteamyeartype=${tmpdir}/$(basename ${fteamyear} .bib)_${aerestype}.bib
      rm ${fteamyeartype} 2> /dev/null
      bibtool_command="bibtool -- 'select={aerestype \"${aerestype}\"}' ${fteamyear} -o ${fteamyeartype}"
      eval ${bibtool_command}
      unset bibtool_command
      # test if empty
      nbatteamyeartype=$(grep -c @ ${fteamyeartype})
      if [ ${nbatteamyeartype} -ge 2 ]
      then
          echo "${command} : ${LINENO} : iii : $((${nbatteamyeartype} - 1)) ref type ${aerestype} in ${fteamyear}"
          ofteamyeartype=${dirwww}/$(basename ${fteamyeartype} .bib).rtf
          rm ${ofteamyeartype} 2> /dev/null
          jabref_rtf \
          ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
          ${fteamyeartype} ${ofteamyeartype}
          # ++ test si ok
      else
          echo "${command} : ${LINENO} : www : no ref type ${aerestype} in ${fteamyear}"
      fi
      unset nbatteamyeartype
   done # end of loop on fteamyear
done # end of loop on aerestype
#
# loop on authors to build bibliography reference file
iauthor=1
nbauthor=${#list_author_bibtool[@]}
#++nbauthor=0 #+++
while [ ${iauthor} -le ${nbauthor} ]
do
   rm ${tmpdir}/tmp1.bib 2> /dev/null
   echo "author title = ${list_author_title[iauthor]}"
   echo "author grep = ${list_author_bibtool[iauthor]}"
   biblioref_author=${tmpdir}/${list_author_file[iauthor]}.bib
   bibtool_command="bibtool -- 'select={author \"${list_author_bibtool[iauthor]}\"}' ${biblioref} -o ${tmpdir}/tmp1.bib"
   eval ${bibtool_command}
   # test if no file found ++
   cat ${tmpdir}/header_jabref ${tmpdir}/tmp1.bib > ${biblioref_author}
   format=locean_tablerefsabsbibsort
   # generation one HTML file style ${format}
   rm ${biblioref}.${format}.jabref.html 2> /dev/null
   java -jar ${JABREF_DIR}/JabRef-${JABREF_VERSION}.jar -n true \
      -p ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
      --output ${dirwww}/${output_title}_${list_author_file[iauthor]}.${format}.jabref.html,${format} \
      ${biblioref_author}
   jabref_status=${?}
   if [ ${jabref_status} -ne 0 ]
   then
      echo "${command} : ${LINENO} : eee : pb with jabref export ${format}"
      exit 1
   fi
#++ else
#++ echo "${command} : ${LINENO} : iii : no reference for author ${team}"
#++ fi
   iauthor=$(( ${iauthor} + 1 ))
done
echo "fin auteurs"

# phybiocar = team with theme
fteam=${tmpdir}/phybiocar.bib
rm ${fteam} 2> /dev/null
bibtool_command="bibtool -- 'select={aeresteam \"phybiocar\"}' ${biblioref} -o ${fteam}"
eval ${bibtool_command}
unset bibtool_command
nbatteam=$(grep -c @ ${fteam})
if [ ${nbatteam} -ge 2 ]
then
    echo "${command} : ${LINENO} : iii : $((${nbatteam} - 1)) ref for aeresteam phybiocar in ${biblioref}"
    # generation one HTML file style ${format}
    format=locean_tablerefsabsbibsort
    rm ${biblioref}.${format}.jabref.html 2> /dev/null
        java -jar ${JABREF_DIR}/JabRef-${JABREF_VERSION}.jar -n true \
       -p ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
       --output ${dirwww}/${output_title}_phybiocar.${format}.jabref.html,${format} \
       ${fteam}
    jabref_status=${?}
    if [ ${jabref_status} -ne 0 ]
    then
       echo "${command} : ${LINENO} : eee : pb with jabref export ${format}"
       exit 1
    fi
    # loop on themes
    list_theme="1 2 3"
    list_fteamtheme=""
    for theme in ${list_theme}
    do
        echo "${command} : ${LINENO} : iii : theme = ${theme}"
        fteamtheme=${tmpdir}/$(basename ${fteam} .bib)_${theme}.bib
        rm  ${fteamtheme} 2> /dev/null
        bibtool_command="bibtool -- 'select={phybiocartheme \"${theme}\"}' ${fteam} -o ${fteamtheme}"
        eval ${bibtool_command}
        unset bibtool_command
        # test if empty
        nbatteamtheme=$(grep -c @ ${fteamtheme})
        if [ ${nbatteamtheme} -ge 2 ]
        then
               echo "${command} : ${LINENO} : iii : $((${nbatteamtheme} - 1)) ref for aeresteam phybiocar and theme ${theme} in ${fteam}"
               list_fteamtheme="${list_fteamtheme} ${fteamtheme}"
        else
               echo "${command} : ${LINENO} : www : no ref for aeresteam phybiocar and theme ${theme}"
        fi
        unset nbatteamtheme
        # loop on years
        list_fteamthemeyear=""
        list_year=$(seq 2007 2012)
        for iyear in ${list_year}
        do
           echo "${command} : ${LINENO} : iii : year = ${iyear}"
           fteamthemeyear=${tmpdir}/$(basename ${fteam} .bib)_${theme}_${iyear}.bib
           rm  ${fteamthemeyear} 2> /dev/null
           bibtool_command="bibtool -- 'select={year \"${iyear}\"}' ${fteamtheme} -o ${fteamthemeyear}"
           eval ${bibtool_command}
           unset bibtool_command
           # test if empty
           nbatteamthemeyear=$(grep -c @ ${fteamthemeyear})
           if [ ${nbatteamthemeyear} -ge 2 ]
           then
               echo "${command} : ${LINENO} : iii : $((${nbatteamthemeyear} - 1)) ref for aeresteam phybiocar and theme ${theme} and year ${iyear}"
               list_fteamthemeyear="${list_fteamthemeyear} ${fteamthemeyear}"
           else
               echo "${command} : ${LINENO} : www : no ref for aeresteam phybiocar and theme ${theme} and year ${iyear}"
           fi
           #read a
           unset nbatteamthemeyear
       done # end of year loop
   done # end of them loop
   unset iyear
else
   echo "${command} : ${LINENO} : www : no ref for aeresteam phybiocar]"
fi
unset list_year
unset fteam
#
# define jabref header
# ++ usefull
jabref_header ${tmpdir}/header_jabref
#
# loop on aerestype
list_aerestype="ACL ACLN ASCL BRE C-INV C-ACTI C-ATCN C-COM C-AFF DO OR OS PV PAT PT AP"
for aerestype in ${list_aerestype}
do
   echo "${command} : ${LINENO} : iii : aerestype = ${aerestype}"
   for fteamthemeyear in ${list_fteamthemeyear}
   do
      echo "${command} : ${LINENO} : iii : fteamthemeyear = ${fteamthemeyear}"
      #++ add header
      fteamthemeyeartype=${tmpdir}/$(basename ${fteamthemeyear} .bib)_${aerestype}.bib
      rm ${fteamthemeyeartype} 2> /dev/null
      bibtool_command="bibtool -- 'select={aerestype \"${aerestype}\"}' ${fteamthemeyear} -o ${fteamthemeyeartype}"
      eval ${bibtool_command}
      unset bibtool_command
      # test if empty
      nbatteamthemeyeartype=$(grep -c @ ${fteamthemeyeartype})
      if [ ${nbatteamthemeyeartype} -ge 2 ]
      then
          echo "${command} : ${LINENO} : iii : $((${nbatteamthemeyeartype} - 1)) ref type ${aerestype} in ${fteamthemeyear}"
          ofteamthemeyeartype=${dirwww}/$(basename ${fteamthemeyeartype} .bib).rtf
          rm ${ofteamthemeyeartype} 2> /dev/null
          jabref_rtf \
          ${PROJECT}/../branches/bibliolocean/src/jabref.preferences.xml \
          ${fteamthemeyeartype} ${ofteamthemeyeartype}
          # ++ test si ok
      else
          echo "${command} : ${LINENO} : www : no ref type ${aerestype} in ${fteamthemeyear}"
      fi
      unset nbatteamthemeyeartype
   done # end of loop on fteamthemeyear
done # end of loop on aerestype
#
#++rm ${biblioref} 2> /dev/null
#++rm ${tmpdir}/header_jabref 2> /dev/null

exit 0
